@@ -369,6 +369,7 @@ class AzureBlobFileSystem(AsyncFileSystem):
         client_id: str = None,
         client_secret: str = None,
         tenant_id: str = None,
+        location_mode: str = "primary",
         loop=None,
         asynchronous: bool = False,
         default_fill_cache: bool = True,
@@ -390,6 +391,7 @@ class AzureBlobFileSystem(AsyncFileSystem):
         self.client_id = client_id or os.getenv("AZURE_STORAGE_CLIENT_ID")
         self.client_secret = client_secret or os.getenv("AZURE_STORAGE_CLIENT_SECRET")
         self.tenant_id = tenant_id or os.getenv("AZURE_STORAGE_TENANT_ID")
+        self.location_mode = location_mode
         self.credential = credential
         self.request_session = request_session
         self.socket_timeout = socket_timeout
@@ -486,7 +488,9 @@ class AzureBlobFileSystem(AsyncFileSystem):
                 if any(creds):
                     self.service_client = [
                         AIOBlobServiceClient(
-                            account_url=self.account_url, credential=cred
+                            account_url=self.account_url,
+                            credential=cred,
+                            _location_mode=self.location_mode,
                         )
                         for cred in creds
                         if cred is not None
@@ -495,7 +499,9 @@ class AzureBlobFileSystem(AsyncFileSystem):
                     if not self.sas_token.startswith("?"):
                         self.sas_token = f"?{self.sas_token}"
                     self.service_client = AIOBlobServiceClient(
-                        account_url=self.account_url + self.sas_token, credential=None
+                        account_url=self.account_url + self.sas_token,
+                        credential=None,
+                        _location_mode=self.location_mode,
                     )
                 else:
                     self.service_client = AIOBlobServiceClient(
@@ -570,7 +576,7 @@ class AzureBlobFileSystem(AsyncFileSystem):
         out = await self._ls(
             self._parent(path), invalidate_cache=invalidate_cache, **kwargs
         )
-        out = [o for o in out if (o["name"].rstrip("/") + "/") == path]
+        out = [o for o in out if o["name"].rstrip("/") == path]
         if out:
             return out[0]
         out = await self._ls(path, invalidate_cache=invalidate_cache, **kwargs)
@@ -1348,10 +1354,10 @@ class AzureBlobFileSystem(AsyncFileSystem):
         )  # Sets whether to return the parent dir
 
         if isinstance(path, list):
-            path = [f"{p.strip('/')}/" for p in path if not p.endswith("*")]
+            path = [f"{p.strip('/')}" for p in path if not p.endswith("*")]
         else:
             if not path.endswith("*"):
-                path = f"{path.strip('/')}/"
+                path = f"{path.strip('/')}"
         if isinstance(path, str):
             out = await self._expand_path(
                 [path], recursive, maxdepth, with_parent=with_parent
@@ -1666,7 +1672,9 @@ class AzureBlobFile(AbstractBufferedFile):
             if any(creds):
                 self.container_client = [
                     AIOBlobServiceClient(
-                        account_url=self.fs.account_url, credential=cred
+                        account_url=self.fs.account_url,
+                        credential=cred,
+                        _location_mode=self.fs.location_mode,
                     ).get_container_client(self.container_name)
                     for cred in creds
                     if cred is not None
